@@ -17,15 +17,13 @@
 
 #include "kstars.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-
 #include <QApplication>
 
 #include <KGlobal>
 #include <KLocale>
 #include <kdebug.h>
 #include <kactioncollection.h>
+#include <kstatusbar.h>
 #include <ktoolbar.h>
 #include <kicon.h>
 
@@ -35,9 +33,8 @@
 #include "skymap.h"
 #include "simclock.h"
 #include "dialogs/finddialog.h"
-#include "imageviewer.h"
 #include "observinglist.h"
-#include "comast/execute.h"
+#include "oal/execute.h"
 
 #include "kstarsadaptor.h"
 
@@ -154,13 +151,17 @@ void KStars::applyConfig( bool doApplyFocus ) {
     }
 
     actionCollection()->action("coordsys")->setText(
-        Options::useAltAz() ? i18n("Horizontal &Coordinates") : i18n("Equatorial &Coordinates") );
+        Options::useAltAz() ? i18n("Switch to star globe view (Equatorial &Coordinates)"): i18n("Switch to horizonal view (Horizontal &Coordinates)") );
+
+    #ifdef HAVE_OPENGL
+    Q_ASSERT( SkyMap::Instance() ); // This assert should not fail, because SkyMap is already created by now. Just throwing it in anyway.
+    actionCollection()->action("opengl")->setText( (Options::useGL() ? i18n("Switch to QPainter backend"): i18n("Switch to OpenGL backend")) );
+    #endif
+
 
     actionCollection()->action("show_time_box"    )->setChecked( Options::showTimeBox() );
     actionCollection()->action("show_location_box")->setChecked( Options::showGeoBox() );
     actionCollection()->action("show_focus_box"   )->setChecked( Options::showFocusBox() );
-    actionCollection()->action("show_mainToolBar" )->setChecked( Options::showMainToolBar() );
-    actionCollection()->action("show_viewToolBar" )->setChecked( Options::showViewToolBar() );
     actionCollection()->action("show_statusBar"   )->setChecked( Options::showStatusBar() );
     actionCollection()->action("show_sbAzAlt"     )->setChecked( Options::showAltAzField() );
     actionCollection()->action("show_sbRADec"     )->setChecked( Options::showRADecField() );
@@ -174,6 +175,7 @@ void KStars::applyConfig( bool doApplyFocus ) {
     actionCollection()->action("show_grid"        )->setChecked( Options::showGrid() );
     actionCollection()->action("show_horizon"     )->setChecked( Options::showGround() );
     actionCollection()->action("show_flags"       )->setChecked( Options::showFlags() );
+    statusBar()->setVisible( Options::showStatusBar() );
 
     //color scheme
     kstarsData->colorScheme()->loadFromConfig();
@@ -197,7 +199,7 @@ void KStars::applyConfig( bool doApplyFocus ) {
     
         if ( ! fo ) {
             SkyPoint fp( Options::focusRA(), Options::focusDec() );
-            if ( fp.ra()->Degrees() != map()->focus()->ra()->Degrees() || fp.dec()->Degrees() != map()->focus()->dec()->Degrees() ) {
+            if ( fp.ra().Degrees() != map()->focus()->ra().Degrees() || fp.dec().Degrees() != map()->focus()->dec().Degrees() ) {
                 map()->setClickedPoint( &fp );
                 map()->slotCenter();
             }
@@ -219,7 +221,7 @@ void KStars::updateTime( const bool automaticDSTchange ) {
     //displayed in the infobox to update every second.
     //	if ( !Options::isTracking() && LST()->Degrees() > oldLST.Degrees() ) {
     //		int nSec = int( 3600.*( LST()->Hours() - oldLST.Hours() ) );
-    //		Map->focus()->setRA( Map->focus()->ra()->Hours() + double( nSec )/3600. );
+    //		Map->focus()->setRA( Map->focus()->ra().Hours() + double( nSec )/3600. );
     //		if ( Options::useAltAz() ) Map->focus()->EquatorialToHorizontal( LST(), geo()->lat() );
     //		Map->showFocusCoords();
     //	}
