@@ -1,12 +1,12 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2009 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2009 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 
@@ -14,7 +14,7 @@
 
 #include <cmath>
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 // #define DEBUG_DRAW_NODES
 
@@ -145,9 +145,9 @@ void ClipPainter::drawPolygon ( const QPolygonF & polygon,
 
         foreach( const QPolygonF & clippedPolyObject, clippedPolyObjects ) { 
             if ( clippedPolyObject.size() > 2 ) {
-                // qDebug() << "Size: " << clippedPolyObject.size();
+                // mDebug() << "Size: " << clippedPolyObject.size();
                 QPainter::drawPolygon ( clippedPolyObject, fillRule );
-                // qDebug() << "done";
+                // mDebug() << "done";
                 #ifdef DEBUG_DRAW_NODES
                     d->debugDrawNodes( clippedPolyObject );
                 #endif
@@ -174,9 +174,9 @@ void ClipPainter::drawPolyline( const QPolygonF & polygon )
 
         foreach( const QPolygonF & clippedPolyObject, clippedPolyObjects ) { 
             if ( clippedPolyObject.size() > 1 ) {
-                // qDebug() << "Size: " << clippedPolyObject.size();
+                // mDebug() << "Size: " << clippedPolyObject.size();
                 QPainter::drawPolyline ( clippedPolyObject );
-                // qDebug() << "done";
+                // mDebug() << "done";
 
                 #ifdef DEBUG_DRAW_NODES
                     d->debugDrawNodes( clippedPolyObject );
@@ -206,9 +206,9 @@ void ClipPainter::drawPolyline( const QPolygonF & polygon, QVector<QPointF>& lab
 
         foreach( const QPolygonF & clippedPolyObject, clippedPolyObjects ) { 
             if ( clippedPolyObject.size() > 1 ) {
-                // qDebug() << "Size: " << clippedPolyObject.size();
+                // mDebug() << "Size: " << clippedPolyObject.size();
                 QPainter::drawPolyline ( clippedPolyObject );
-                // qDebug() << "done";
+                // mDebug() << "done";
 
                 #ifdef DEBUG_DRAW_NODES
                     d->debugDrawNodes( clippedPolyObject );
@@ -292,7 +292,8 @@ void ClipPainterPrivate::labelPosition( const QPolygonF & polygon, QVector<QPoin
     }
 }
 
-bool ClipPainterPrivate::pointAllowsLabel( const QPointF& point ){
+bool ClipPainterPrivate::pointAllowsLabel( const QPointF& point )
+{
 
     if ( point.x() > m_labelAreaMargin && point.x() < q->viewport().width() - m_labelAreaMargin 
          && point.y() > m_labelAreaMargin && point.y() < q->viewport().height() - m_labelAreaMargin ) {
@@ -303,7 +304,8 @@ bool ClipPainterPrivate::pointAllowsLabel( const QPointF& point ){
 
 QPointF ClipPainterPrivate::interpolateLabelPoint( const QPointF& previousPoint, 
                                                    const QPointF& currentPoint,
-                                                   LabelPositionFlags labelPositionFlags ) {
+                                                   LabelPositionFlags labelPositionFlags )
+{
     qreal m = _m( previousPoint, currentPoint );
     if ( previousPoint.x() <= m_labelAreaMargin ) {
         if ( labelPositionFlags.testFlag( IgnoreXMargin ) ) {
@@ -337,7 +339,7 @@ QPointF ClipPainterPrivate::interpolateLabelPoint( const QPointF& previousPoint,
                           q->viewport().height() - m_labelAreaMargin );        
     }
 
-//    qDebug() << Q_FUNC_INFO << "Previous and current node position are allowed!";
+//    mDebug() << Q_FUNC_INFO << "Previous and current node position are allowed!";
 
     return QPointF( -1.0, -1.0 );
 }
@@ -403,7 +405,7 @@ QPointF ClipPainterPrivate::clipRight( qreal m, const QPointF & point ) const
 
 int ClipPainterPrivate::sector( const QPointF & point ) const
 {
-    // If we think of the image borders as (infinitly long) parallel
+    // If we think of the image borders as (infinitely long) parallel
     // lines then the plane is divided into 9 sectors.  Each of these
     // sections is identified by a unique keynumber (currentSector):
     //
@@ -437,7 +439,7 @@ void ClipPainterPrivate::clipPolyObject ( const QPolygonF & polygon,
                                           QVector<QPolygonF> & clippedPolyObjects,
                                           bool isClosed )
 {
-    //	qDebug() << "ClipPainter enabled." ;
+    //	mDebug() << "ClipPainter enabled." ;
 
     // Only create a new polyObject as soon as we know for sure that 
     // the current point is on the screen. 
@@ -455,7 +457,7 @@ void ClipPainterPrivate::clipPolyObject ( const QPolygonF & polygon,
 
     while ( itPoint != itEndPoint ) {
         m_currentPoint = (*itPoint);
-        // qDebug() << "m_currentPoint.x()" << m_currentPoint.x() << "m_currentPOint.y()" << m_currentPoint.y();
+        // mDebug() << "m_currentPoint.x()" << m_currentPoint.x() << "m_currentPOint.y()" << m_currentPoint.y();
 
         // Figure out the sector of the current point.
         m_currentSector = sector( m_currentPoint );
@@ -484,8 +486,8 @@ void ClipPainterPrivate::clipPolyObject ( const QPolygonF & polygon,
             }
             else {
                 // This case mostly deals with lines that reach from one
-                // sector that is located offscreen to another one that
-                // is located offscreen. In this situation the line 
+                // sector that is located off screen to another one that
+                // is located off screen. In this situation the line 
                 // can get clipped once, twice, or not at all.
                 clipMultiple( clippedPolyObject, clippedPolyObjects, isClosed );
             }
@@ -533,7 +535,7 @@ void ClipPainterPrivate::clipMultiple( QPolygonF & clippedPolyObject,
     Q_UNUSED( isClosed )
 
     // Take care of adding nodes in the image corners if the iterator 
-    // traverses offscreen sections.
+    // traverses off screen sections.
 
     qreal  m = _m( m_previousPoint, m_currentPoint );
 
@@ -1058,7 +1060,7 @@ void ClipPainterPrivate::clipOnce( QPolygonF & clippedPolyObject,
     // Calculating the slope.
     qreal m = _m( m_previousPoint, m_currentPoint );
 
-    // Calculate in which sector the end of the line is located that is offscreen 
+    // Calculate in which sector the end of the line is located that is off screen 
     int offscreenpos = ( m_currentSector == 4 ) ? m_previousSector : m_currentSector;
 
     // "Rise over run" for all possible situations .
@@ -1115,7 +1117,8 @@ void ClipPainterPrivate::clipOnce( QPolygonF & clippedPolyObject,
 
 #ifdef DEBUG_DRAW_NODES
 
-void ClipPainterPrivate::debugDrawNodes( const QPolygonF & polygon ) {
+void ClipPainterPrivate::debugDrawNodes( const QPolygonF & polygon )
+{
 
     q->save();
     q->setRenderHint( QPainter::Antialiasing, false );
