@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -11,7 +11,6 @@
 #ifndef MARBLE_KMLFILEVIEWITEM_H
 #define MARBLE_KMLFILEVIEWITEM_H
 
-#include "AbstractFileViewItem.h"
 #include "GeoDataDocument.h"
 
 namespace Marble
@@ -19,24 +18,20 @@ namespace Marble
 
 class FileManager;
 
-class KmlFileViewItem : public AbstractFileViewItem
+class KmlFileViewItem
 {
   public:
-    KmlFileViewItem( FileManager &manager, const GeoDataDocument& document );
+    KmlFileViewItem( GeoDataDocument *document );
     ~KmlFileViewItem();
 
-    /*
-     * AbstractFileViewItem methods
-     */
-    virtual void saveFile();
-    virtual bool isShown() const;
-    virtual void setShown( bool value );
-    virtual QString name() const;
+    void saveFile();
+    bool isShown() const;
+    void setShown( bool value );
+    QString name() const;
 
     GeoDataDocument* document();
   private:
-    FileManager  &m_fileManager;
-    GeoDataDocument    m_document;
+    GeoDataDocument    *m_document;
 };
 
 }
