@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -141,6 +141,10 @@ class MARBLE_EXPORT AbstractProjection
                             const ViewportParams *viewport,
                             qreal &x, qreal &y );
 
+    bool screenCoordinates( const GeoDataCoordinates &geopoint,
+                            const ViewportParams *viewport,
+                            QPointF &screenpoint );
+
     /**
      * @brief Get the coordinates of screen points for geographical coordinates in the map.
      *
@@ -169,9 +173,9 @@ class MARBLE_EXPORT AbstractProjection
                                     bool &globeHidesPoint ) = 0;
 
 
-    virtual bool screenCoordinates( const GeoDataLineString &lineString, 
-                                    const ViewportParams *viewport,
-                                    QVector<QPolygonF*> &polygons );
+    bool screenCoordinates( const GeoDataLineString &lineString,
+                            const ViewportParams *viewport,
+                            QVector<QPolygonF*> &polygons );
 
     /**
      * @brief Get the earth coordinates corresponding to a pixel in the map.
