@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -14,6 +14,8 @@
 
 #include <QtCore/QDataStream>
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
@@ -31,15 +33,9 @@ class GeoDataHotSpotPrivate
     {
     }
 
-    GeoDataHotSpotPrivate( const GeoDataHotSpotPrivate& other )
-        : m_hotSpot( other.m_hotSpot ),
-          m_xunits( other.m_xunits ),
-          m_yunits( other.m_yunits )
-    {
-    }
-
-    ~GeoDataHotSpotPrivate()
+    QString nodeType() const
     {
+        return GeoDataTypes::GeoDataHotspotType;
     }
 
     QPointF m_hotSpot;
@@ -86,6 +82,11 @@ void GeoDataHotSpot::setHotSpot( const QPointF& hotSpot, Units xunits, Units yun
     d->m_yunits = yunits;
 }
 
+QString GeoDataHotSpot::nodeType() const
+{
+    return d->nodeType();
+}
+
 void GeoDataHotSpot::pack( QDataStream& stream ) const
 {
     GeoDataObject::pack( stream );
