@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -13,6 +13,8 @@
 
 #include <QtGui/QFont>
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 #ifdef Q_OS_MACX
