@@ -27,6 +27,9 @@
 #include "GeoDataParser.h"
 
 #include "GeoDataDocument.h"
+#include "GeoDataStyle.h"
+#include "GeoDataStyleMap.h"
+#include "global.h"
 
 namespace Marble
 {
@@ -37,9 +40,23 @@ GPX_DEFINE_TAG_HANDLER(gpx)
 GeoNode* GPXgpxTagHandler::parse(GeoParser& parser) const
 {
     GeoDataDocument* doc = geoDataDoc( parser );
-//#ifdef DEBUG_TAGS
+
+    GeoDataStyle style;
+    GeoDataLineStyle lineStyle;
+    lineStyle.setColor( oxygenForestGreen4 );
+    lineStyle.setWidth(2);
+    style.setLineStyle(lineStyle);
+    style.setStyleId("track");
+
+    GeoDataStyleMap styleMap;
+    styleMap.setStyleId("map-track");
+    styleMap.insert("normal", QString("#").append(style.styleId()));
+    doc->addStyleMap(styleMap);
+    doc->addStyle(style);
+
+#ifdef DEBUG_TAGS
     mDebug() << "Parsed <" << gpxTag_gpx << "> document: " << doc;
-//#endif
+#endif
     return doc;
 }
 
