@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -22,11 +22,11 @@
 #include "ViewportParams.h"
 #include "MarbleDebug.h"
 #include "MarbleWidget.h"
-#include "MarbleMap.h"
 #include "WidgetGraphicsItem.h"
 #include "MarbleGraphicsGridLayout.h"
 
 using namespace Marble;
+/* TRANSLATOR Marble::NavigationFloatItem */
 
 const int defaultMinZoom = 900;
 const int defaultMaxZoom = 2400;
@@ -42,8 +42,7 @@ NavigationFloatItem::NavigationFloatItem( const QPointF &point )
 {
     // Plugin is enabled by default
     setEnabled( true );
-    // Plugin is visible by default on devices with small screens only
-    setVisible( MarbleGlobal::getInstance()->profiles() & MarbleGlobal::SmallScreen );
+    setVisible( false );
 
     if( m_profiles & MarbleGlobal::SmallScreen ) {
         setFrame( FrameGraphicsItem::RectFrame );
@@ -51,7 +50,7 @@ NavigationFloatItem::NavigationFloatItem( const QPointF &point )
     else {
         setFrame( FrameGraphicsItem::RoundedRectFrame );
     }
-    
+
     // This sets the padding to the minimum possible for this Frame
     setPadding( 0 );
 }
@@ -95,7 +94,7 @@ QIcon NavigationFloatItem::icon() const
 void NavigationFloatItem::initialize()
 {
     QWidget *navigationParent = new QWidget( 0 );
-    
+
     if( m_profiles & MarbleGlobal::SmallScreen ) {
         m_navigationWidgetSmall = new Ui::NavigationSmall;
         m_navigationWidgetSmall->setupUi( navigationParent );
@@ -104,13 +103,13 @@ void NavigationFloatItem::initialize()
         m_navigationWidget = new Ui::Navigation;
         m_navigationWidget->setupUi( navigationParent );
     }
-    
+
     m_widgetItem = new WidgetGraphicsItem( this );
     m_widgetItem->setWidget( navigationParent );
-    
+
     MarbleGraphicsGridLayout *layout = new MarbleGraphicsGridLayout( 1, 1 );
     layout->addItem( m_widgetItem, 0, 0 );
-    
+
     setLayout( layout );
 
     if( !( m_profiles & MarbleGlobal::SmallScreen ) ) {
@@ -140,7 +139,7 @@ void NavigationFloatItem::changeViewport( ViewportParams *viewport )
     }
 }
 
-bool NavigationFloatItem::eventFilter(QObject *object, QEvent *e)
+bool NavigationFloatItem::eventFilter( QObject *object, QEvent *e )
 {
     if ( !enabled() || !visible() ) {
         return false;
@@ -148,16 +147,16 @@ bool NavigationFloatItem::eventFilter(QObject *object, QEvent *e)
 
     MarbleWidget *widget = dynamic_cast<MarbleWidget*> (object);
     if ( !widget ) {
-        return AbstractFloatItem::eventFilter(object, e);
+        return AbstractFloatItem::eventFilter( object, e );
     }
 
     if ( m_marbleWidget != widget ) {
         // Delayed initialization
         m_marbleWidget = widget;
-        int minZoom = m_marbleWidget->map()->minimumZoom();
-        int maxZoom = m_marbleWidget->map()->maximumZoom();
+        int minZoom = m_marbleWidget->minimumZoom();
+        int maxZoom = m_marbleWidget->maximumZoom();
         //m_navigationWidget->zoomSlider->setRange(minZoom, maxZoom);
-        
+
         if( m_profiles & MarbleGlobal::SmallScreen ) {
             connect( m_navigationWidgetSmall->zoomInButton, SIGNAL( clicked() ),
                      m_marbleWidget, SLOT( zoomIn() ) );
@@ -169,9 +168,9 @@ bool NavigationFloatItem::eventFilter(QObject *object, QEvent *e)
         else {
             m_navigationWidget->zoomSlider->setMinimum(minZoom);
             m_navigationWidget->zoomSlider->setMaximum(maxZoom);
-            m_navigationWidget->zoomSlider->setValue(m_marbleWidget->map()->zoom());
+            m_navigationWidget->zoomSlider->setValue(m_marbleWidget->zoom());
             m_navigationWidget->zoomSlider->setTickInterval((maxZoom - minZoom) / 15);
-        
+
             connect( m_navigationWidget->zoomInButton, SIGNAL( clicked() ),
                      m_marbleWidget, SLOT( zoomIn() ) );
             connect( m_navigationWidget->zoomOutButton, SIGNAL( clicked() ),
@@ -185,26 +184,26 @@ bool NavigationFloatItem::eventFilter(QObject *object, QEvent *e)
                      m_marbleWidget, SLOT( moveUp() ) );
             connect( m_navigationWidget->moveDownButton, SIGNAL( clicked() ),
                      m_marbleWidget, SLOT( moveDown() ) );
-        
+
             connect( m_navigationWidget->goHomeButton, SIGNAL( clicked() ),
                      m_marbleWidget, SLOT( goHome() ) );
         }
-        
-        connect( m_marbleWidget->map(), SIGNAL( zoomChanged(int) ),
+
+        connect( m_marbleWidget, SIGNAL( zoomChanged(int) ),
                  this, SLOT( setZoomSliderValue( int ) ) );
         connect( m_marbleWidget, SIGNAL( themeChanged( QString ) ),
                  this, SLOT( selectTheme( QString ) ) );
-        
-        updateButtons( m_marbleWidget->map()->zoom() );
+
+        updateButtons( m_marbleWidget->zoom() );
     }
 
     return AbstractFloatItem::eventFilter(object, e);
 }
 
-void NavigationFloatItem::setZoomSliderValue(int level)
+void NavigationFloatItem::setZoomSliderValue( int level )
 {
     if( !( m_profiles & MarbleGlobal::SmallScreen ) ) {
-        m_navigationWidget->zoomSlider->setValue(level);
+        m_navigationWidget->zoomSlider->setValue( level );
     }
 }
 
@@ -212,7 +211,7 @@ void NavigationFloatItem::setMarbleZoomValue( int level )
 {
     // There exists a circular signal/slot connection between MarbleWidget and this widget's
     // zoom slider. MarbleWidget prevents recursion, but it still loops one time unless
-    // disconnected here. 
+    // disconnected here.
     // The circular signal/slot connection results into the Marble Globe flickering, when the
     // zoom slider is used.
 
@@ -220,26 +219,26 @@ void NavigationFloatItem::setMarbleZoomValue( int level )
         return;
     }
 
-    disconnect( m_marbleWidget->map(), SIGNAL( zoomChanged(int) ),
+    disconnect( m_marbleWidget, SIGNAL( zoomChanged(int) ),
                 this, SLOT( setZoomSliderValue( int ) ) );
     m_marbleWidget->zoomView( level );
-    connect( m_marbleWidget->map(), SIGNAL( zoomChanged(int) ),
+    connect( m_marbleWidget, SIGNAL( zoomChanged(int) ),
                 this, SLOT( setZoomSliderValue( int ) ) );
 }
 
-void NavigationFloatItem::selectTheme(QString theme)
+void NavigationFloatItem::selectTheme( QString theme )
 {
     Q_UNUSED(theme);
-    
+
     if ( m_marbleWidget ) {
         if( m_profiles & MarbleGlobal::SmallScreen ) {
-            updateButtons( m_marbleWidget->map()->zoom() );
+            updateButtons( m_marbleWidget->zoom() );
         }
         else {
-            int minZoom = m_marbleWidget->map()->minimumZoom();
-            int maxZoom = m_marbleWidget->map()->maximumZoom();
+            int minZoom = m_marbleWidget->minimumZoom();
+            int maxZoom = m_marbleWidget->maximumZoom();
             m_navigationWidget->zoomSlider->setRange( minZoom, maxZoom );
-            m_navigationWidget->zoomSlider->setValue( m_marbleWidget->map()->zoom() );
+            m_navigationWidget->zoomSlider->setValue( m_marbleWidget->zoom() );
             updateButtons( m_navigationWidget->zoomSlider->value() );
         }
     }
@@ -261,61 +260,56 @@ void NavigationFloatItem::adjustForStill()
     }
 
     m_marbleWidget->setViewContext( Still );
-
-    if ( m_marbleWidget->mapQuality( Still )
-        != m_marbleWidget->mapQuality( Animation ) ) {
-        m_marbleWidget->updateChangedMap();
-    }
 }
 
-void NavigationFloatItem::updateButtons( int value )
+void NavigationFloatItem::updateButtons( int zoomValue )
 {
     int minZoom = defaultMinZoom;
     int maxZoom = defaultMaxZoom;
-    QToolButton *zoomInButton;
-    QToolButton *zoomOutButton;
-    
+    QToolButton *zoomInButton = 0;
+    QToolButton *zoomOutButton = 0;
+
     if( m_profiles & MarbleGlobal::SmallScreen ) {
         if ( m_marbleWidget ) {
-            minZoom = m_marbleWidget->map()->minimumZoom();
-            maxZoom = m_marbleWidget->map()->maximumZoom();
+            minZoom = m_marbleWidget->minimumZoom();
+            maxZoom = m_marbleWidget->maximumZoom();
         }
-        
+
         zoomInButton = m_navigationWidgetSmall->zoomInButton;
         zoomOutButton = m_navigationWidgetSmall->zoomOutButton;
     }
     else {
         minZoom = m_navigationWidget->zoomSlider->minimum();
         maxZoom = m_navigationWidget->zoomSlider->maximum();
-        
+
         zoomInButton = m_navigationWidget->zoomInButton;
         zoomOutButton = m_navigationWidget->zoomOutButton;
     }
-    
-    if ( value <= minZoom ) {
+
+    if ( zoomValue <= minZoom ) {
         zoomInButton->setEnabled( true );
         zoomOutButton->setEnabled( false );
-    } else if ( value >= maxZoom ) {
+    } else if ( zoomValue >= maxZoom ) {
         zoomInButton->setEnabled( false );
         zoomOutButton->setEnabled( true );
     } else {
         zoomInButton->setEnabled( true );
         zoomOutButton->setEnabled( true );
     }
-    
+
     if (m_marbleWidget)
     {
         // Trigger a repaint of the float item. Otherwise button state updates
         // are delayed
         QRectF floatItemRect = QRectF( positivePosition(), size() ).toRect();
         QRegion dirtyRegion( floatItemRect.toRect() );
-    
+
         m_marbleWidget->setAttribute( Qt::WA_NoSystemBackground, false );
 
         update();
 
         m_marbleWidget->setAttribute( Qt::WA_NoSystemBackground,
-                                      m_marbleWidget->map()->mapCoversViewport() );
+                                      m_marbleWidget->viewport()->mapCoversViewport() );
     }
 }
 
