@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -15,9 +15,11 @@
 
 class QIcon;
 
-namespace Marble {
+namespace Marble
+{
 
-class PhotoPlugin : public AbstractDataPlugin {
+class PhotoPlugin : public AbstractDataPlugin
+{
     Q_OBJECT
     Q_INTERFACES( Marble::RenderPluginInterface )
     MARBLE_PLUGIN( PhotoPlugin )
@@ -26,6 +28,8 @@ class PhotoPlugin : public AbstractDataPlugin {
     PhotoPlugin();
      
     void initialize();
+
+    bool isInitialized () const;
     
     QString name() const;
     
@@ -34,6 +38,8 @@ class PhotoPlugin : public AbstractDataPlugin {
     QString description() const;
     
     QIcon icon() const;
+ private:
+    bool m_isInitialized;
 };
 
 }
