@@ -18,13 +18,14 @@
  ***************************************************************************/
 
 #include "krossBackend.h"
-#include "graph.h"
-#include "node.h"
+#include "DataType.h"
+#include "Data.h"
 #include <KDebug>
 #include <KTextBrowser>
 #include "graphDocument.h"
 #include <QScriptEngineDebugger>
 #include <unistd.h> // usleep
+#include <ToolsPluginInterface.h>
 
 static QtScriptBackend *self;
 
@@ -33,79 +34,81 @@ static QScriptValue debug_script(QScriptContext* context, QScriptEngine* /*engin
     return QScriptValue();
 }
 
-static QScriptValue output_script(QScriptContext *context, QScriptEngine* /*engine*/){
+static QScriptValue output_script(QScriptContext *context, QScriptEngine* /*engine*/) {
     self->output(QString("%1 \n").arg(context->argument(0).toString()));
     return QScriptValue();
 }
 
-void QtScriptBackend::stop(){
-      kDebug() << "Stop requested.";
-      if (!_engine) return;
-      
-      if (_engine->isEvaluating()){
+void QtScriptBackend::stop() {
+    kDebug() << "Stop requested.";
+    if (!_engine) return;
+
+    if (_engine->isEvaluating()) {
         _engine->abortEvaluation();
-      }
-      _engine->deleteLater();
-      _engine = 0;
-      emit finished();
+    }
+    _engine->deleteLater();
+    _engine = 0;
+    emit finished();
 }
 
 void QtScriptBackend::start()
 {
     stop();
-    
+
     _engine = new QScriptEngine();
     emit engineCreated(_engine);
     usleep(500);
-    
+
     _engine->globalObject().setProperty("debug",  engine()->newFunction(debug_script));
     _engine->globalObject().setProperty("output", engine()->newFunction(output_script));
     kDebug() << "ScriptBackend Created";
-    
+
     int size = _graphs->size();
     for (int i = 0; i < size; i++) {
-	kDebug() << "Setting graph" << i << "as global object";
+        kDebug() << "Setting graph" << i << "as global object";
         _graphs->at(i)->setEngine(_engine);
     }
     kDebug() << "Setting the graph list";
     createGraphList();
-   
+
     kDebug() << "Evaluating the script";
     QString error = _engine->evaluate(_script).toString();
-    while( _engine && _engine->isEvaluating() ){
-	usleep(200000); /// rest a bit.
+    while ( _engine && _engine->isEvaluating() ) {
+        usleep(200000); /// rest a bit.
     }
-   kDebug() << "Script evaluated to " << error;
-   
-    emit finished(); kDebug() << "Finished emmited";
-    emit sendDebug(error); kDebug() << "send debug emmited";
+    kDebug() << "Script evaluated to " << error;
+
+    emit finished();
+    kDebug() << "Finished emmited";
+    emit sendDebug(error);
+    kDebug() << "send debug emmited";
 }
 
-bool QtScriptBackend::isRunning(){
-  if ((_engine) && (_engine->isEvaluating())){
+bool QtScriptBackend::isRunning() {
+    if ((_engine) && (_engine->isEvaluating())) {
         return true;
-  }
-  return _runningTool;
+    }
+    return _runningTool;
 }
-    
 
-QtScriptBackend::QtScriptBackend(){
+QtScriptBackend::QtScriptBackend(QObject* parent): QObject(parent) {
     self = this;
     _engine = 0;
     _runningTool = false;
 }
 
-void QtScriptBackend::runTool(Rocs::ToolsPluginInterface * plugin, GraphDocument *graphs){
+
+void QtScriptBackend::runTool(Rocs::ToolsPluginInterface * plugin, DataTypeDocument *graphs) {
     _runningTool = true;
     _graphs = graphs;
     _script = plugin->run(graphs);
-    if ( !_script.isEmpty()){
-      start();
+    if ( !_script.isEmpty()) {
+        start();
     }
     _runningTool = false;
 }
 
-void QtScriptBackend::setScript(const QString& s,GraphDocument *graphs ) {
+void QtScriptBackend::setScript(const QString& s,DataTypeDocument *graphs ) {
     _script = s;
     _graphs = graphs;
     kDebug() << "script Set" << _script;
@@ -138,11 +141,11 @@ void QtScriptBackend::loadFile(const QString& file) {
     _script += '\n';
 }
 
-void QtScriptBackend::debug(const QString& str){
-     emit sendDebug(str);
+void QtScriptBackend::debug(const QString& str) {
+    emit sendDebug(str);
 }
 
-void QtScriptBackend::output(const QString& str){
+void QtScriptBackend::output(const QString& str) {
     emit sendOutput(str);
 }
 
